Hi! I download and send audios from videos/tracks/sets/albums in *MP3 128 kbps* with tags and artwork.
• Send or forward a message containing links in my PM and I will download immediately.
• Send or forward a message containing links in groups with me and I will ask you.
• [Privacy mode](https://core.telegram.org/bots#privacy-mode) is _disabled_, so I scan every group message for links.
• `/dl <links>` to download immediately.
• `/link <links>` to get direct download URLs only.
• /clutter to toggle replies and spam captions on / off.
• Files over 50 MB (bot-sent size limit) are split into parts.
• Supported links and resources:
*SoundCloud*: tracks/playlists/pages with private widgets
*Bandcamp*: tracks/albums/custom links
*YouTube*: videos/playlists/no lives
*Mixcloud, Vimeo and* [everything from this list](https://rg3.github.io/youtube-dl/supportedsites.html) (no VK music)

*Example message:*
`Check it out! https://m.soundcloud.com/richarddjames/umil-25-01 and also https://shitmat.bandcamp.com/track/amen-babylon-2016-mix and youtu.be/Mdzy5RKn434`

*Credits / Emoji-links:*
[🌟 @GitHub](https://github.com/gpchelkin/scdlbot) / [⌨️⚠](https://github.com/gpchelkin/scdlbot/issues)
👨🏻‍💻 @gpchelkin / [🐝👍](http://pchelk.in/)
👩🏻‍🎨 @lowonbudget / [🎨🖼️](https://www.behance.net/lowonbudget)
🎶 @electrocircle / [⚡⚫](https://t.me/Eklight)
